Module pack

Module pack 

Pack helpers. Contains Builder, builder for Pack.

Structs

Builder
Main builder for pack. Inside it keeps list of File under respective PackPath.

Functions

store_file
Serializes pack to given file path Serialized data can be used with load method of loader.
store_memory
Serializes pack to AlignedVec. Serialized data can be used with load method of loader.