Structs
Functions
- store_
file - Serializes
packto given file path Serialized data can be used withloadmethod of loader. - store_
memory - Serializes
packto AlignedVec. Serialized data can be used withloadmethod of loader.
pack to given file path Serialized data can be used with load
method of loader.pack to AlignedVec. Serialized data can be used with load
method of loader.